@@ -92,7 +92,7 @@ def setup(app):
     )
 
     pkgdir = os.path.abspath(os.path.dirname(__file__))
-    locale_dir = os.path.join(pkgdir, "locale")
+    locale_dir = os.path.join(pkgdir, "locales")
     app.config.locale_dirs.append(locale_dir)
 
     return {"version": __version__}  # identifies the version of our extension
@@ -100,7 +100,14 @@ def setup(app):
 
 def config_inited(app, config):
     app.config.templates_path.append(get_html_templates_path())
-    app.config.matched_blog_posts = [os.path.splitext(ii)[0] for ii in glob(config.blog_post_pattern)]
+
+    # Automatically identify any blog posts if a pattern is specified in the config
+    if isinstance(config.blog_post_pattern, str):
+        config.blog_post_pattern = [config.blog_post_pattern]
+    matched_patterns = []
+    for pattern in config.blog_post_pattern:
+        matched_patterns.extend(os.path.splitext(ii)[0] for ii in glob(pattern, recursive=True))
+    app.config.matched_blog_posts = matched_patterns
 
 
 def get_html_templates_path():
